pub struct Runtime(/* private fields */);Expand description
A type-erased RuntimeTrait implementation. Think of this as an Arc<dyn RuntimeTrait>
Implementations
Sourceimpl Runtime
impl Runtime
Sourcepub fn new(runtime: impl RuntimeTrait) -> Self
pub fn new(runtime: impl RuntimeTrait) -> Self
Construct a new type-erased runtime object from any RuntimeTrait implementation.
Sourcepub fn spawn<Output: Send + 'static>(
&self,
fut: impl Future<Output = Output> + Send + 'static,
) -> DroppableFuture<Pin<Box<dyn Future<Output = Option<Output>> + Send + 'static>>> ⓘ
pub fn spawn<Output: Send + 'static>( &self, fut: impl Future<Output = Output> + Send + 'static, ) -> DroppableFuture<Pin<Box<dyn Future<Output = Option<Output>> + Send + 'static>>> ⓘ
Spawn a future on the runtime, returning a future that has detach-on-drop semantics
Spawned tasks conform to the following behavior:
-
detach on drop: If the returned
DroppableFutureis dropped immediately, the task will continue to execute until completion. -
unwinding: If the spawned future panics, this must not propagate to the join handle. Instead, the awaiting the join handle returns None in case of panic.
Sourcepub fn spawn_detached<Fut>(&self, fut: Fut)
pub fn spawn_detached<Fut>(&self, fut: Fut)
Spawn a future on the runtime without a join handle.
Cheaper than spawn when the caller doesn’t need the output or
completion signal: no channel or join-handle allocation is made.
Sourcepub fn interval(&self, period: Duration) -> impl Stream<Item = ()> + Send + '_
pub fn interval(&self, period: Duration) -> impl Stream<Item = ()> + Send + '_
Returns a Stream that yields a () on the provided period