pub type BoxedBidiStream = Box<dyn QuicTransportBidi + Unpin + Send + Sync>;Expand description
A type-erased QuicTransportBidi stream — Box<dyn QuicTransportBidi + Unpin + Send + Sync>.
Aliased Type
pub struct BoxedBidiStream(/* private fields */);Trait Implementations
impl QuicTransportBidi for BoxedBidiStream
Sourceimpl QuicTransportSend for BoxedBidiStream
impl QuicTransportSend for BoxedBidiStream
Sourcefn reset(&mut self, code: u64)
fn reset(&mut self, code: u64)
Close the send stream immediately with the provided error code.
Sourcefn set_priority(&mut self, priority: i32)
fn set_priority(&mut self, priority: i32)
Set this stream’s transmission priority relative to other streams on the same
connection. Higher values are sent first when the connection is send-constrained. Read more
Sourceimpl Transport for BoxedBidiStream
impl Transport for BoxedBidiStream
Sourcefn set_linger(&mut self, linger: Option<Duration>) -> Result<()>
fn set_linger(&mut self, linger: Option<Duration>) -> Result<()>
Sets the linger duration of this transport by setting the
SO_LINGER option Read moreSourcefn set_nodelay(&mut self, nodelay: bool) -> Result<()>
fn set_nodelay(&mut self, nodelay: bool) -> Result<()>
Sets the value of the
TCP_NODELAY option on this transport. Read moreSourcefn set_ip_ttl(&mut self, ttl: u32) -> Result<()>
fn set_ip_ttl(&mut self, ttl: u32) -> Result<()>
Sets the value for the
IP_TTL option on this transport. Read more