pub type BoxedSendStream = Box<dyn QuicTransportSend + Unpin + Send + Sync>;Expand description
A type-erased QuicTransportSend stream — Box<dyn QuicTransportSend + Unpin + Send + Sync>.
Aliased Type
pub struct BoxedSendStream(/* private fields */);Trait Implementations
Sourceimpl QuicTransportSend for BoxedSendStream
impl QuicTransportSend for BoxedSendStream
Sourcefn reset(&mut self, code: u64)
fn reset(&mut self, code: u64)
Close the send stream immediately with the provided error code.
Sourcefn set_priority(&mut self, priority: i32)
fn set_priority(&mut self, priority: i32)
Set this stream’s transmission priority relative to other streams on the same
connection. Higher values are sent first when the connection is send-constrained. Read more