pub trait QuicTransportSend: AsyncWrite {
// Required method
fn reset(&mut self, code: u64);
// Provided method
fn set_priority(&mut self, _priority: i32) { ... }
}Expand description
Abstraction over the outbound half of a QUIC stream (both bidi and outbound uni)
Required Methods
Provided Methods
Sourcefn set_priority(&mut self, _priority: i32)
fn set_priority(&mut self, _priority: i32)
Set this stream’s transmission priority relative to other streams on the same connection. Higher values are sent first when the connection is send-constrained.
The default does nothing, for transports without per-stream prioritization.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".